@@ -3,10 +3,8 @@
 
 #include <libxml/tree.h>
 
-#include "cache.h"
 #include "remoteapi.h"
 #include "rss/feed.h"
-#include "3rd-party/json.hpp"
 #include "utils.h"
 
 class CurlHandle;
@@ -17,7 +15,7 @@ namespace newsboat {
 
 class FreshRssApi : public RemoteApi {
 public:
-	explicit FreshRssApi(ConfigContainer* c);
+	explicit FreshRssApi(ConfigContainer& c);
 	~FreshRssApi() override = default;
 	bool authenticate() override;
 	std::vector<TaggedFeedUrl> get_subscribed_urls() override;
@@ -27,7 +25,6 @@ public:
 	bool update_article_flags(const std::string& oldflags,
 		const std::string& newflags,
 		const std::string& guid) override;
-	rsspp::Feed fetch_feed(const std::string& id);
 	rsspp::Feed fetch_feed(const std::string& id, CurlHandle& cached_handle);
 
 private:
