@@ -13,7 +13,7 @@ public:
 	~HelpFormAction() override = default;
 	void prepare() override;
 	void init() override;
-	const std::vector<KeyMapHintEntry>& get_keymap_hint() const override;
+	std::vector<KeyMapHintEntry> get_keymap_hint() const override;
 	std::string id() const override
 	{
 		return "help";
