@@ -1,12 +1,11 @@
 #ifndef NEWSBOAT_LISTFORMATTER_H_
 #define NEWSBOAT_LISTFORMATTER_H_
 
-#include <climits>
 #include <string>
-#include <utility>
 #include <vector>
 
 #include "regexmanager.h"
+#include "stflrichtext.h"
 
 namespace newsboat {
 
@@ -14,9 +13,8 @@ class ListFormatter {
 public:
 	ListFormatter(RegexManager* r = nullptr, const std::string& loc = "");
 	~ListFormatter();
-	void add_line(const std::string& text);
-	void set_line(const unsigned int itempos,
-		const std::string& text);
+	void add_line(const StflRichText& text);
+	void set_line(const unsigned int itempos, const StflRichText& text);
 	void clear()
 	{
 		lines.clear();
@@ -28,7 +26,7 @@ public:
 	}
 
 private:
-	std::vector<std::string> lines;
+	std::vector<StflRichText> lines;
 	RegexManager* rxman;
 	std::string location;
 };
