@@ -9,8 +9,8 @@
 namespace newsboat {
 
 namespace opml {
-xmlDocPtr generate(const FeedContainer& feedcontainer);
-bool import(
+xmlDocPtr generate(const FeedContainer& feedcontainer, bool version2);
+nonstd::optional<std::string> import(
 	const std::string& filename,
 	FileUrlReader& urlcfg);
 }
