@@ -16,39 +16,27 @@ namespace podboat {
 
 class PbView;
 
-class QueueLoader;
-
 class PbController {
 public:
 	PbController();
-	~PbController();
-	void set_view(PbView* vv)
-	{
-		v = vv;
-	}
+	~PbController() = default;
+
 	void initialize(int argc, char* argv[]);
-	int run();
+	int run(PbView& v);
+
+	newsboat::KeyMap& get_keymap();
 
-	bool view_update_necessary() const
-	{
-		return view_update_;
-	}
-	void set_view_update_necessary(bool b)
-	{
-		view_update_ = b;
-	}
 	std::vector<Download>& downloads()
 	{
 		return downloads_;
 	}
 
-	std::string get_formatstr();
-
 	unsigned int downloads_in_progress();
 	void purge_queue();
 
 	unsigned int get_maxdownloads();
 	void start_downloads();
+	void start_download(Download& item);
 
 	void increase_parallel_downloads();
 	void decrease_parallel_downloads();
@@ -59,7 +47,7 @@ public:
 
 	newsboat::ConfigContainer* get_cfgcont()
 	{
-		return cfg;
+		return &cfg;
 	}
 
 	const newsboat::ColorManager& get_colormanager()
@@ -71,22 +59,16 @@ private:
 	void print_usage(const char* argv0);
 	bool setup_dirs_xdg(const char* env_home);
 
-	PbView* v;
 	std::string config_file;
 	std::string queue_file;
-	newsboat::ConfigContainer* cfg;
-	bool view_update_;
+	newsboat::ConfigContainer cfg;
 	std::vector<Download> downloads_;
 
 	std::string config_dir;
-	std::string url_file;
-	std::string cache_file;
-	std::string searchfile;
-	std::string cmdlinefile;
 
 	unsigned int max_dls;
 
-	QueueLoader* ql;
+	std::unique_ptr<QueueLoader> ql;
 
 	std::string lock_file;
 	std::unique_ptr<newsboat::FsLock> fslock;
