@@ -1,8 +1,6 @@
 #ifndef NEWSBOAT_RELOADTHREAD_H_
 #define NEWSBOAT_RELOADTHREAD_H_
 
-#include <thread>
-
 #include "configcontainer.h"
 #include "controller.h"
 
@@ -10,7 +8,7 @@ namespace newsboat {
 
 class ReloadThread {
 public:
-	ReloadThread(Controller* c, ConfigContainer* cf);
+	ReloadThread(Controller* c, ConfigContainer& cf);
 	virtual ~ReloadThread();
 	void operator()();
 
@@ -19,7 +17,7 @@ private:
 	time_t oldtime;
 	time_t waittime_sec;
 	bool suppressed_first;
-	ConfigContainer* cfg;
+	ConfigContainer& cfg;
 };
 
 } // namespace newsboat
