@@ -23,7 +23,9 @@ public:
 		TTRSS_JSON,
 		NEWSBLUR_JSON,
 		OCNEWS_JSON,
-		MINIFLUX_JSON
+		MINIFLUX_JSON,
+		FEEDBIN_JSON,
+		FRESHRSS_JSON
 	};
 
 	Feed()
