@@ -5,6 +5,7 @@
 #include <libxml/parser.h>
 #include <string>
 
+#include "3rd-party/optional.hpp"
 #include "remoteapi.h"
 #include "feed.h"
 
@@ -32,7 +33,7 @@ public:
 		newsboat::RemoteApi* api = 0,
 		const std::string& cookie_cache = "");
 	Feed parse_buffer(const std::string& buffer,
-		const std::string& url = "");
+		const std::string& url = "", nonstd::optional<std::string> charset = nonstd::nullopt);
 	Feed parse_file(const std::string& filename);
 	time_t get_last_modified()
 	{
