@@ -17,8 +17,10 @@ fn main() {
     add_cxxbridge("fmtstrformatter");
     add_cxxbridge("fslock");
     add_cxxbridge("history");
+    add_cxxbridge("keycombination");
     add_cxxbridge("keymap");
     add_cxxbridge("logger");
     add_cxxbridge("scopemeasure");
+    add_cxxbridge("stflrichtext");
     add_cxxbridge("utils");
 }
