@@ -88,6 +88,8 @@ mod bridged {
         fn translit(tocode: &str, fromcode: &str) -> String;
         fn utf8_to_locale(text: &str) -> Vec<u8>;
         fn locale_to_utf8(text: &[u8]) -> String;
+        fn convert_text(text: &[u8], tocode: &str, fromcode: &str) -> Vec<u8>;
+        fn string_from_utf8_lossy(text: &[u8]) -> String;
     }
 }
 
@@ -242,6 +244,10 @@ fn podcast_mime_to_link_type(mime_type: &str, result: &mut i64) -> bool {
     }
 }
 
+fn string_from_utf8_lossy(text: &[u8]) -> String {
+    String::from_utf8_lossy(text).to_string()
+}
+
 #[no_mangle]
 pub unsafe extern "C" fn rs_get_string(line: *const c_char) -> *mut c_char {
     let line = CStr::from_ptr(line);
