@@ -16,9 +16,11 @@ pub mod filterparser;
 pub mod fmtstrformatter;
 pub mod fslock;
 pub mod history;
+pub mod keycombination;
 pub mod keymap;
 pub mod links;
 pub mod matchable;
 pub mod matcher;
 pub mod matchererror;
 pub mod scopemeasure;
+pub mod stflrichtext;
