@@ -9,21 +9,17 @@ fn t_cliargsparser_dash_i_resolves_tilde_to_homedir() {
     env::set_var("HOME", tmp.path());
 
     let filename = "feedlist.opml";
-    let arg = format!("~/{}", filename);
+    let arg = format!("~/{filename}");
 
     let check = |opts| {
         let args = CliArgsParser::new(opts);
         assert_eq!(args.importfile, Some(tmp.path().join(filename)));
     };
 
-    check(vec![
-        "newsboat".to_string(),
-        "-i".to_string(),
-        arg.to_string(),
-    ]);
+    check(vec!["newsboat".into(), "-i".into(), arg.clone().into()]);
 
     check(vec![
-        "newsboat".to_string(),
-        "--import-from-opml=".to_string() + &arg,
+        "newsboat".into(),
+        format!("--import-from-opml={}", &arg).into(),
     ]);
 }
