@@ -7,7 +7,6 @@
 #include <iostream>
 #include <libgen.h>
 #include <sstream>
-#include <stdexcept>
 
 #include "config.h"
 #include "logger.h"
@@ -63,33 +62,13 @@ HtmlRenderer::HtmlRenderer(bool raw)
 
 void HtmlRenderer::render(const std::string& source,
 	std::vector<std::pair<LineType, std::string>>& lines,
-	std::vector<LinkPair>& links,
+	Links& links,
 	const std::string& url)
 {
 	std::istringstream input(source);
 	render(input, lines, links, url);
 }
 
-unsigned int HtmlRenderer::add_link(std::vector<LinkPair>& links,
-	const std::string& link,
-	LinkType type)
-{
-	bool found = false;
-	unsigned int i = 1;
-	for (const auto& l : links) {
-		if (l.first == link) {
-			found = true;
-			break;
-		}
-		i++;
-	}
-	if (!found) {
-		links.push_back(LinkPair(link, type));
-	}
-
-	return i;
-}
-
 HtmlTag HtmlRenderer::extract_tag(TagSoupPullParser& parser)
 {
 	std::string tagname = parser.get_text();
@@ -102,7 +81,7 @@ HtmlTag HtmlRenderer::extract_tag(TagSoupPullParser& parser)
 
 void HtmlRenderer::render(std::istream& input,
 	std::vector<std::pair<LineType, std::string>>& lines,
-	std::vector<LinkPair>& links,
+	Links& links,
 	const std::string& url)
 {
 	unsigned int image_count = 0;
@@ -174,10 +153,9 @@ void HtmlRenderer::render(std::istream& input,
 					LOG(Level::WARN, "HtmlRenderer::render: found a tag with no href attribute");
 				}
 				if (link.length() > 0) {
-					link_num = add_link(links,
-							utils::censor_url(
-								utils::absolute_url(
-									url, link)),
+					link_num = links.add_link(
+							utils::absolute_url(
+								url, link),
 							LinkType::HREF);
 					if (!raw_) {
 						curline.append("<u>");
@@ -218,11 +196,10 @@ void HtmlRenderer::render(std::istream& input,
 						LOG(Level::WARN, "HtmlRenderer::render: found embed object without src attribute");
 					}
 					if (link.length() > 0) {
-						link_num = add_link(links,
-								utils::censor_url(
-									utils::absolute_url(
-										url,
-										link)),
+						link_num = links.add_link(
+								utils::absolute_url(
+									url,
+									link),
 								LinkType::EMBED);
 						curline.append(strprintf::fmt(
 								"[%s %u]",
@@ -551,11 +528,8 @@ void HtmlRenderer::render(std::istream& input,
 				// have a closing tag
 				if (inside_video || inside_audio) {
 					source_count = 0;
-					inside_video = false;
 					inside_audio = false;
-					LOG(Level::WARN,
-						"HtmlRenderer::render: "
-						"media element left unclosed");
+					LOG(Level::WARN, "HtmlRenderer::render: media element left unclosed");
 				}
 				inside_video = true;
 
@@ -577,6 +551,10 @@ void HtmlRenderer::render(std::istream& input,
 					add_media_link(curline, links, url,
 						video_url, "", video_count,
 						LinkType::VIDEO);
+
+					add_line(curline, tables, lines);
+					prepare_new_line(curline,
+						tables.size() ? 0 : indent_level);
 				}
 			}
 			break;
@@ -598,10 +576,7 @@ void HtmlRenderer::render(std::istream& input,
 				if (inside_video || inside_audio) {
 					source_count = 0;
 					inside_video = false;
-					inside_audio = false;
-					LOG(Level::WARN,
-						"HtmlRenderer::render: "
-						"media element left unclosed");
+					LOG(Level::WARN, "HtmlRenderer::render: media element left unclosed");
 				}
 				inside_audio = true;
 
@@ -623,6 +598,10 @@ void HtmlRenderer::render(std::istream& input,
 					add_media_link(curline, links, url,
 						audio_url, "", audio_count,
 						LinkType::AUDIO);
+
+					add_line(curline, tables, lines);
+					prepare_new_line(curline,
+						tables.size() ? 0 : indent_level);
 				}
 			}
 			break;
@@ -642,12 +621,20 @@ void HtmlRenderer::render(std::istream& input,
 					add_media_link(curline, links, url,
 						source_url, "", video_count,
 						LinkType::VIDEO);
+
+					add_line(curline, tables, lines);
+					prepare_new_line(curline,
+						tables.size() ? 0 : indent_level);
 				}
 				if (inside_audio && !source_url.empty()) {
 					source_count++;
 					add_media_link(curline, links, url,
 						source_url, "", audio_count,
 						LinkType::AUDIO);
+
+					add_line(curline, tables, lines);
+					prepare_new_line(curline,
+						tables.size() ? 0 : indent_level);
 				}
 			}
 			}
@@ -1018,23 +1005,10 @@ void HtmlRenderer::render(std::istream& input,
 			add_line_nonwrappable(s, lines);
 		}
 	}
-
-	// add link list
-	if (links.size() > 0) {
-		add_line("", tables, lines);
-		add_line(_("Links: "), tables, lines);
-		for (unsigned int i = 0; i < links.size(); ++i) {
-			auto link_text = strprintf::fmt("[%u]: %s (%s)",
-					i + 1,
-					links[i].first,
-					type2str(links[i].second));
-			add_line_softwrappable(link_text, lines);
-		}
-	}
 }
 
 void HtmlRenderer::add_media_link(std::string& curline,
-	std::vector<LinkPair>& links, const std::string& url,
+	Links& links, const std::string& url,
 	const std::string& media_url, const std::string& media_title,
 	unsigned int media_count, LinkType type)
 {
@@ -1047,8 +1021,8 @@ void HtmlRenderer::add_media_link(std::string& curline,
 		link_url = utils::censor_url(utils::absolute_url(url, media_url));
 	}
 
-	const std::string type_str = type2str(type);
-	const unsigned int link_num = add_link(links, link_url, type);
+	const std::string type_str = Links::type2str(type);
+	const unsigned int link_num = links.add_link(link_url, type);
 	std::string output;
 
 	if (!media_title.empty()) {
@@ -1070,26 +1044,6 @@ std::string HtmlRenderer::render_hr(const unsigned int width)
 	return result;
 }
 
-std::string HtmlRenderer::type2str(LinkType type)
-{
-	switch (type) {
-	case LinkType::HREF:
-		return _("link");
-	case LinkType::IMG:
-		return _("image");
-	case LinkType::EMBED:
-		return _("embedded flash");
-	case LinkType::IFRAME:
-		return _("iframe");
-	case LinkType::VIDEO:
-		return _("video");
-	case LinkType::AUDIO:
-		return _("audio");
-	default:
-		return _("unknown (bug)");
-	}
-}
-
 void HtmlRenderer::add_nonempty_line(const std::string& curline,
 	std::vector<Table>& tables,
 	std::vector<std::pair<LineType, std::string>>& lines)
