@@ -1,8 +1,5 @@
 #include "pbcontroller.h"
 
-#include <cinttypes>
-#include <cstdint>
-#include <cstdio>
 #include <cstdlib>
 #include <cstring>
 #include <getopt.h>
@@ -11,15 +8,16 @@
 #include <signal.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <memory>
 #include <thread>
 #include <unistd.h>
 
+#include "3rd-party/optional.hpp"
 #include "config.h"
 #include "configcontainer.h"
 #include "configexception.h"
 #include "configparser.h"
 #include "logger.h"
-#include "matcherexception.h"
 #include "nullconfigactionhandler.h"
 #include "pbview.h"
 #include "poddlthread.h"
@@ -182,6 +180,7 @@ void PbController::initialize(int argc, char* argv[])
 	static const struct option longopts[] = {
 		{"config-file", required_argument, 0, 'C'},
 		{"queue-file", required_argument, 0, 'q'},
+		{"lock-file", required_argument, 0, 256},
 		{"log-file", required_argument, 0, 'd'},
 		{"log-level", required_argument, 0, 'l'},
 		{"help", no_argument, 0, 'h'},
@@ -189,6 +188,8 @@ void PbController::initialize(int argc, char* argv[])
 		{"version", no_argument, 0, 'v'},
 		{0, 0, 0, 0}
 	};
+	nonstd::optional<Level> log_level;
+	nonstd::optional<std::string> log_file;
 
 	while ((c = ::getopt_long(argc, argv, getopt_str, longopts, nullptr)) !=
 		-1) {
@@ -203,21 +204,22 @@ void PbController::initialize(int argc, char* argv[])
 		case 'q':
 			queue_file = optarg;
 			break;
+		case 256:
+			lock_file = optarg;
+			break;
 		case 'a':
 			automatic_dl = true;
 			break;
 		case 'd':
-			logger::set_logfile(optarg);
+			log_file = optarg;
 			break;
 		case 'l': {
-			Level l = static_cast<Level>(atoi(optarg));
-			if (l >= Level::USERERROR && l <= Level::DEBUG) {
-				logger::set_loglevel(l);
-			} else {
+			log_level = static_cast<Level>(atoi(optarg));
+			if (log_level < Level::USERERROR || log_level > Level::DEBUG) {
 				std::cerr << strprintf::fmt(_("%s: %d: invalid "
 							"loglevel value"),
 						argv[0],
-						static_cast<int>(l))
+						static_cast<int>(log_level.value()))
 					<< std::endl;
 				exit(EXIT_FAILURE);
 			}
@@ -229,11 +231,26 @@ void PbController::initialize(int argc, char* argv[])
 		}
 	};
 
+	if (log_level.has_value()) {
+		logger::set_loglevel(log_level.value());
+	}
+
+	if (log_file.has_value()) {
+		logger::set_logfile(log_file.value());
+	}
+
+	if (!log_file.has_value() && log_level.has_value()) {
+		const std::string date_time_string = utils::mt_strf_localtime("%Y-%m-%d_%H.%M.%S",
+				std::time(nullptr));
+		const std::string filename = "podboat_" + date_time_string + ".log";
+		logger::set_logfile(filename);
+	}
+
 	std::cout << strprintf::fmt(
 			_("Starting %s %s..."), "Podboat", utils::program_version())
 		<< std::endl;
 
-	fslock = std::unique_ptr<FsLock>(new FsLock());
+	fslock = std::make_unique<FsLock>();
 	pid_t pid;
 	std::string error_message;
 	if (!fslock->try_lock(lock_file, pid, error_message)) {
@@ -288,9 +305,9 @@ int PbController::run(PbView& v)
 
 	std::cout << _("done.") << std::endl;
 
-	ql.reset(new QueueLoader(queue_file, cfg, [&]() {
+	ql = std::make_unique<QueueLoader>(queue_file, cfg, [&]() {
 		v.set_view_update_necessary();
-	}));
+	});
 	ql->reload(downloads_);
 
 	v.run(automatic_dl, cfg.get_configvalue_as_bool("wrap-scroll"));
@@ -332,47 +349,64 @@ void PbController::print_usage(const char* argv0)
 		{
 			'C',
 			"config-file",
-			_s("<configfile>"),
-			_s("read configuration from <configfile>")
+			_s("<file>"),
+			_s("read configuration from <file>")
 		},
 		{
 			'q',
 			"queue-file",
-			_s("<queuefile>"),
-			_s("use <queuefile> as queue file")
+			_s("<file>"),
+			_s("use <file> as podcast queue file")
+		},
+		{
+			'-',
+			"lock-file",
+			_s("<file>"),
+			_s("use <file> as lock file")
 		},
 		{'a', "autodownload", "", _s("start download on startup")},
 		{
 			'l',
 			"log-level",
 			_s("<loglevel>"),
-			_s("write a log with a certain loglevel (valid values: "
-				"1 to "
-				"6)")
+			_s("write a log with a certain log level (valid values: 1 to 6,"
+				" for user error, critical, error, warning, info, and debug respectively)")
 		},
 		{
 			'd',
 			"log-file",
-			_s("<logfile>"),
-			_s("use <logfile> as output log file")
+			_s("<file>"),
+			_s("use <file> as output log file")
 		},
 		{'h', "help", "", _s("this help")}
 	};
 
+	std::vector<std::pair<std::string, std::string>> helpLines;
+	std::size_t maxLength = 0;
 	for (const auto& a : args) {
-		std::string longcolumn("-");
-		longcolumn += a.name;
-		longcolumn += ", --" + a.longname;
-		longcolumn += a.params.size() > 0 ? "=" + a.params : "";
-		std::cout << "\t" << longcolumn;
-		for (unsigned int j = 0; j < utils::gentabs(longcolumn); j++) {
-			std::cout << "\t";
+		std::string longcolumn;
+		if (a.name != '-') {
+			longcolumn += "-";
+			longcolumn += a.name;
+			longcolumn += ", ";
+		} else {
+			longcolumn += "    ";
 		}
-		std::cout << a.desc << std::endl;
-	}
+		longcolumn += "--" + a.longname;
+		longcolumn += a.params.size() > 0 ? "=" + a.params : "";
 
-	std::cout << std::endl
-		<< _("Support at #newsboat at https://libera.chat or on our mailing "
+		maxLength = std::max(maxLength, longcolumn.length());
+		helpLines.push_back({longcolumn, a.desc});
+	}
+	for (const auto& helpLine : helpLines) {
+		std::cout << std::string(8, ' ') << helpLine.first;
+		const auto padding = maxLength - helpLine.first.length();
+		std::cout << std::string(2 + padding, ' ') << helpLine.second;
+		std::cout << std::endl;
+	}
+	std::cout << std::endl;
+
+	std::cout << _("Support at #newsboat at https://libera.chat or on our mailing "
 			"list https://groups.google.com/g/newsboat")
 		<< std::endl
 		<< _("For more information, check out https://newsboat.org/")
@@ -430,7 +464,7 @@ void PbController::start_downloads()
 
 void PbController::start_download(Download& item)
 {
-	std::thread t{PodDlThread(&item, &cfg)};
+	std::thread t{PodDlThread(&item, cfg)};
 	t.detach();
 }
 
