@@ -3,7 +3,6 @@
 #include <cstring>
 #include <cinttypes>
 #include <curl/curl.h>
-#include <iostream>
 #include <libgen.h>
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -11,7 +10,6 @@
 #include <unistd.h>
 
 #include "curlhandle.h"
-#include "config.h"
 #include "logger.h"
 #include "utils.h"
 
@@ -27,7 +25,7 @@ static int progress_callback(void* clientp,
 	curl_off_t ultotal,
 	curl_off_t ulnow);
 
-PodDlThread::PodDlThread(Download* dl_, newsboat::ConfigContainer* c)
+PodDlThread::PodDlThread(Download* dl_, newsboat::ConfigContainer& c)
 	: dl(dl_)
 	, f(new std::ofstream())
 	, bytecount(0)
@@ -66,7 +64,7 @@ void PodDlThread::run()
 	curl_easy_setopt(handle.ptr(), CURLOPT_XFERINFODATA, this);
 
 	// set up max download speed
-	int max_dl_speed = cfg->get_configvalue_as_int("max-download-speed");
+	int max_dl_speed = cfg.get_configvalue_as_int("max-download-speed");
 	if (max_dl_speed > 0) {
 		curl_easy_setopt(handle.ptr(),
 			CURLOPT_MAX_RECV_SPEED_LARGE,
