@@ -184,6 +184,19 @@ std::string utils::locale_to_utf8(const std::string& text)
 	return std::string(utils::bridged::locale_to_utf8(text_slice));
 }
 
+std::string utils::convert_text(const std::string& text, const std::string& tocode,
+	const std::string& fromcode)
+{
+	const auto text_slice =
+		rust::Slice<const unsigned char>(
+			reinterpret_cast<const unsigned char*>(text.c_str()),
+			text.length());
+
+	const auto result = utils::bridged::convert_text(text_slice, tocode, fromcode);
+
+	return std::string(reinterpret_cast<const char*>(result.data()), result.size());
+}
+
 std::string utils::get_command_output(const std::string& cmd)
 {
 	return std::string(utils::bridged::get_command_output(cmd));
@@ -375,6 +388,17 @@ std::string utils::replace_all(const std::string& str,
 	return output;
 }
 
+std::string utils::to_lowercase(const std::string& input)
+{
+	std::string output;
+	std::transform(input.begin(), input.end(), std::back_inserter(output),
+	[](unsigned char c) {
+		return std::tolower(c);
+	});
+
+	return output;
+}
+
 std::string utils::preserve_quotes(const std::string& str)
 {
 	std::string escaped_string = "";
@@ -765,6 +789,13 @@ nonstd::optional<LinkType> utils::podcast_mime_to_link_type(
 	return nonstd::nullopt;
 }
 
+std::string utils::string_from_utf8_lossy(const std::vector<std::uint8_t>& text)
+{
+	auto input = rust::Slice<std::uint8_t const>(text.data(), text.size());
+	auto result = utils::bridged::string_from_utf8_lossy(input);
+	return std::string(result);
+}
+
 /*
  * See
  * http://curl.haxx.se/libcurl/c/libcurl-tutorial.html#Multi-threading
