@@ -4,15 +4,16 @@
 
 #include "confighandlerexception.h"
 #include "matchable.h"
+#include "stflrichtext.h"
 
 using namespace newsboat;
 
 TEST_CASE("RegexManager throws on invalid command", "[RegexManager]")
 {
 	RegexManager rxman;
-	std::vector<std::string> params;
 
 	SECTION("on invalid command") {
+		std::vector<std::string> params;
 		REQUIRE_THROWS_AS(
 			rxman.handle_action("an-invalid-command", params),
 			ConfigHandlerException);
@@ -65,20 +66,19 @@ TEST_CASE("RegexManager doesn't throw on valid `highlight' definition",
 TEST_CASE("RegexManager highlights according to definition", "[RegexManager]")
 {
 	RegexManager rxman;
-	std::string input;
 
 	SECTION("In articlelist") {
 		rxman.handle_action("highlight", {"articlelist", "foo", "blue", "red"});
-		input = "xfoox";
+		auto input = StflRichText::from_plaintext("xfoox");
 		rxman.quote_and_highlight(input, "articlelist");
-		REQUIRE(input == "x<0>foo</>x");
+		REQUIRE(input.stfl_quoted() == "x<0>foo</>x");
 	}
 
 	SECTION("In feedlist") {
 		rxman.handle_action("highlight", {"feedlist", "foo", "blue", "red"});
-		input = "yfooy";
+		auto input = StflRichText::from_plaintext("yfooy");
 		rxman.quote_and_highlight(input, "feedlist");
-		REQUIRE(input == "y<0>foo</>y");
+		REQUIRE(input.stfl_quoted() == "y<0>foo</>y");
 	}
 }
 
@@ -86,18 +86,18 @@ TEST_CASE("quote_and_highlight() only matches `^` at the start of the line",
 	"[RegexManager]")
 {
 	RegexManager rxman;
-	std::string input = "This is a test";
+	auto input = StflRichText::from_quoted("This is a test");
 
 	SECTION("^.") {
 		rxman.handle_action("highlight", {"article", "^.", "blue", "red"});
 		rxman.quote_and_highlight(input, "article");
-		REQUIRE(input == "<0>T</>his is a test");
+		REQUIRE(input.stfl_quoted() == "<0>T</>his is a test");
 	}
 
 	SECTION("(^Th|^is)") {
 		rxman.handle_action("highlight", {"article", "(^Th|^is)", "blue", "red"});
 		rxman.quote_and_highlight(input, "article");
-		REQUIRE(input == "<0>Th</>is is a test");
+		REQUIRE(input.stfl_quoted() == "<0>Th</>is is a test");
 	}
 }
 
@@ -114,27 +114,27 @@ TEST_CASE("RegexManager::quote_and_highlight works fine even if there were "
 	rxman.handle_action("highlight", {"articlelist", "foo", "blue", "red"});
 	rxman.handle_action("highlight-article", {"title==\"\"", "blue", "red"});
 
-	std::string input = "xfoox";
+	auto input = StflRichText::from_plaintext("xfoox");
 	rxman.quote_and_highlight(input, "articlelist");
-	REQUIRE(input == "x<0>foo</>x");
+	REQUIRE(input.stfl_quoted() == "x<0>foo</>x");
 }
 
 TEST_CASE("RegexManager preserves text when there's nothing to highlight",
 	"[RegexManager]")
 {
 	RegexManager rxman;
-	std::string input = "xbarx";
+	auto input = StflRichText::from_plaintext("xbarx");
 	rxman.quote_and_highlight(input, "feedlist");
-	REQUIRE(input == "xbarx");
+	REQUIRE(input.stfl_quoted() == "xbarx");
 
-	input = "a<b>";
+	input = StflRichText::from_quoted("a<b>");
 	rxman.quote_and_highlight(input, "feedlist");
-	REQUIRE(input == "a<b>");
+	REQUIRE(input.stfl_quoted() == "a<b>");
 
 	SECTION("encode `<` as `<>` for stfl") {
-		input = "<";
+		input = StflRichText::from_plaintext("<");
 		rxman.quote_and_highlight(input, "feedlist");
-		REQUIRE(input == "<>");
+		REQUIRE(input.stfl_quoted() == "<>");
 	}
 }
 
@@ -143,14 +143,14 @@ TEST_CASE("`highlight all` adds rules for all locations", "[RegexManager]")
 	RegexManager rxman;
 	std::vector<std::string> params = {"all", "foo", "red"};
 	REQUIRE_NOTHROW(rxman.handle_action("highlight", params));
-	std::string input = "xxfooyy";
+	auto input = StflRichText::from_plaintext("xxfooyy");
 
 	for (auto location : {
 			"article", "articlelist", "feedlist"
 		}) {
 		SECTION(location) {
 			rxman.quote_and_highlight(input, location);
-			REQUIRE(input == "xx<0>foo</>yy");
+			REQUIRE(input.stfl_quoted() == "xx<0>foo</>yy");
 		}
 	}
 }
@@ -159,36 +159,38 @@ TEST_CASE("RegexManager does not hang on regexes that can match empty strings",
 	"[RegexManager]")
 {
 	RegexManager rxman;
-	std::string input = "The quick brown fox jumps over the lazy dog";
+	auto input =
+		StflRichText::from_plaintext("The quick brown fox jumps over the lazy dog");
 
 	rxman.handle_action("highlight", {"feedlist", "w*", "blue", "red"});
 	rxman.quote_and_highlight(input, "feedlist");
-	REQUIRE(input == "The quick bro<0>w</>n fox jumps over the lazy dog");
+	REQUIRE(input.stfl_quoted() == "The quick bro<0>w</>n fox jumps over the lazy dog");
 }
 
 TEST_CASE("RegexManager does not hang on regexes that match empty strings",
 	"[RegexManager]")
 {
 	RegexManager rxman;
-	std::string input = "The quick brown fox jumps over the lazy dog";
-	const std::string compare = input;
+	auto input =
+		StflRichText::from_plaintext("The quick brown fox jumps over the lazy dog");
+	const std::string compare = input.plaintext();
 
 	SECTION("testing end of line empty.") {
 		rxman.handle_action("highlight", {"feedlist", "$", "blue", "red"});
 		rxman.quote_and_highlight(input, "feedlist");
-		REQUIRE(input == compare);
+		REQUIRE(input.stfl_quoted() == compare);
 	}
 
 	SECTION("testing beginning of line empty") {
 		rxman.handle_action("highlight", {"feedlist", "^", "blue", "red"});
 		rxman.quote_and_highlight(input, "feedlist");
-		REQUIRE(input == compare);
+		REQUIRE(input.stfl_quoted() == compare);
 	}
 
 	SECTION("testing empty line") {
 		rxman.handle_action("highlight", {"feedlist", "^$", "blue", "red"});
 		rxman.quote_and_highlight(input, "feedlist");
-		REQUIRE(input == compare);
+		REQUIRE(input.stfl_quoted() == compare);
 	}
 }
 
@@ -196,7 +198,8 @@ TEST_CASE("quote_and_highlight wraps highlighted text in numbered tags",
 	"[RegexManager]")
 {
 	RegexManager rxman;
-	std::string input =  "The quick brown fox jumps over the lazy dog";
+	auto input =
+		StflRichText::from_plaintext("The quick brown fox jumps over the lazy dog");
 
 	SECTION("Beginning of line match first") {
 		const std::string output =
@@ -204,7 +207,7 @@ TEST_CASE("quote_and_highlight wraps highlighted text in numbered tags",
 		rxman.handle_action("highlight", {"article", "the", "red"});
 		rxman.handle_action("highlight", {"article", "brown", "blue"});
 		rxman.quote_and_highlight(input, "article");
-		REQUIRE(input == output);
+		REQUIRE(input.stfl_quoted() == output);
 	}
 
 	SECTION("Beginning of line match second") {
@@ -213,7 +216,7 @@ TEST_CASE("quote_and_highlight wraps highlighted text in numbered tags",
 		rxman.handle_action("highlight", {"article", "brown", "blue"});
 		rxman.handle_action("highlight", {"article", "the", "red"});
 		rxman.quote_and_highlight(input, "article");
-		REQUIRE(input == output);
+		REQUIRE(input.stfl_quoted() == output);
 	}
 
 	SECTION("2 non-overlapping highlights") {
@@ -222,12 +225,13 @@ TEST_CASE("quote_and_highlight wraps highlighted text in numbered tags",
 		rxman.handle_action("highlight", {"article", "quick", "red"});
 		rxman.handle_action("highlight", {"article", "brown", "blue"});
 		rxman.quote_and_highlight(input, "article");
-		REQUIRE(input == output);
+		REQUIRE(input.stfl_quoted() == output);
 	}
 }
 
-TEST_CASE("RegexManager::dump_config turns each `highlight` rule into a string, "
-	"and appends them onto a vector",
+TEST_CASE("RegexManager::dump_config turns each `highlight`, "
+	"`highlight-article` and `highlight-feed` rule into a string, and appends "
+	"them onto a vector",
 	"[RegexManager]")
 {
 	RegexManager rxman;
@@ -251,8 +255,24 @@ TEST_CASE("RegexManager::dump_config turns each `highlight` rule into a string,
 			"highlight-article",
 		{"title==\"\"", "green", "black"});
 		REQUIRE_NOTHROW(rxman.dump_config(result));
-		REQUIRE(result.size() == 1);
+		REQUIRE(result.size() == 2);
 		REQUIRE(result[0] == R"#(highlight "all" "keywords" "red" "blue")#");
+		REQUIRE(result[1] == R"#(highlight-article "title==\"\"" "green" "black")#");
+	}
+
+	SECTION("Three rules") {
+		rxman.handle_action("highlight", {"all", "keywords", "red", "blue"});
+		rxman.handle_action(
+			"highlight-article",
+		{"title==\"\"", "green", "black"});
+		rxman.handle_action(
+			"highlight-feed",
+		{"title==\"\"", "red", "black"});
+		REQUIRE_NOTHROW(rxman.dump_config(result));
+		REQUIRE(result.size() == 3);
+		REQUIRE(result[0] == R"#(highlight "all" "keywords" "red" "blue")#");
+		REQUIRE(result[1] == R"#(highlight-article "title==\"\"" "green" "black")#");
+		REQUIRE(result[2] == R"#(highlight-feed "title==\"\"" "red" "black")#");
 	}
 }
 
@@ -409,10 +429,59 @@ TEST_CASE("RegexManager doesn't throw on valid `highlight-article' definition",
 	REQUIRE_NOTHROW(rxman.handle_action("highlight-article", params));
 }
 
+TEST_CASE("RegexManager throws on invalid `highlight-feed' definition",
+	"[RegexManager]")
+{
+	RegexManager rxman;
+	std::vector<std::string> params;
+
+	SECTION("on `highlight-feed' without parameters") {
+		REQUIRE_THROWS_AS(rxman.handle_action("highlight-feed", params),
+			ConfigHandlerException);
+	}
+
+	SECTION("on invalid filter expression") {
+		params = {"a = b", "red", "green"};
+		REQUIRE_THROWS_AS(rxman.handle_action("highlight-feed", params),
+			ConfigHandlerException);
+	}
+
+	SECTION("on missing colors") {
+		params = {"title==\"\""};
+		REQUIRE_THROWS_AS(rxman.handle_action("highlight-feed", params),
+			ConfigHandlerException);
+	}
+
+	SECTION("on missing background color") {
+		params = {"title==\"\"", "white"};
+		REQUIRE_THROWS_AS(rxman.handle_action("highlight-feed", params),
+			ConfigHandlerException);
+	}
+}
+
+TEST_CASE("RegexManager doesn't throw on valid `highlight-feed' definition",
+	"[RegexManager]")
+{
+	RegexManager rxman;
+	std::vector<std::string> params;
+
+	params = {"title == \"\"", "blue", "red"};
+	REQUIRE_NOTHROW(rxman.handle_action("highlight-feed", params));
+
+	params = {"content =~ \"keyword\"", "blue", "red"};
+	REQUIRE_NOTHROW(rxman.handle_action("highlight-feed", params));
+
+	params = {"unread == \"yes\"", "blue", "red", "bold", "underline"};
+	REQUIRE_NOTHROW(rxman.handle_action("highlight-feed", params));
+
+	params = {"age > 3", "blue", "red", "bold", "underline"};
+	REQUIRE_NOTHROW(rxman.handle_action("highlight-feed", params));
+}
+
 struct RegexManagerMockMatchable : public Matchable {
 public:
 	nonstd::optional<std::string> attribute_value(const std::string& attribname)
-	override
+	const override
 	{
 		if (attribname == "attr") {
 			return "val";
@@ -474,6 +543,59 @@ TEST_CASE("RegexManager::article_matches returns -1 if there are no Matcher "
 	}
 }
 
+TEST_CASE("RegexManager::feed_matches returns position of the Matcher "
+	"that matches a given Matchable",
+	"[RegexManager]")
+{
+	RegexManager rxman;
+	RegexManagerMockMatchable mock;
+
+	const auto cmd = std::string("highlight-feed");
+
+	SECTION("Just one rule") {
+		rxman.handle_action(cmd, {"attr != \"hello\"", "red", "green"});
+
+		REQUIRE(rxman.feed_matches(&mock) == 0);
+	}
+
+	SECTION("Couple rules") {
+		rxman.handle_action(cmd, {"attr != \"val\"", "green", "white"});
+		rxman.handle_action(cmd, {"attr # \"entry\"", "green", "white"});
+		rxman.handle_action(cmd, {"attr == \"val\"", "green", "white"});
+		rxman.handle_action(cmd, {"attr =~ \"hello\"", "green", "white"});
+
+		REQUIRE(rxman.feed_matches(&mock) == 2);
+	}
+}
+
+TEST_CASE("RegexManager::feed_matches returns -1 if there are no Matcher "
+	"to match a given Matchable",
+	"[RegexManager]")
+{
+	RegexManager rxman;
+	RegexManagerMockMatchable mock;
+
+	const auto cmd = std::string("highlight-feed");
+
+	SECTION("No rules") {
+		REQUIRE(rxman.feed_matches(&mock) == -1);
+	}
+
+	SECTION("Just one rule") {
+		rxman.handle_action(cmd, {"attr == \"hello\"", "red", "green"});
+
+		REQUIRE(rxman.feed_matches(&mock) == -1);
+	}
+
+	SECTION("Couple rules") {
+		rxman.handle_action(cmd, {"attr != \"val\"", "green", "white"});
+		rxman.handle_action(cmd, {"attr # \"entry\"", "green", "white"});
+		rxman.handle_action(cmd, {"attr =~ \"hello\"", "green", "white"});
+
+		REQUIRE(rxman.feed_matches(&mock) == -1);
+	}
+}
+
 TEST_CASE("RegexManager::remove_last_regex removes last added `highlight` rule",
 	"[RegexManager]")
 {
@@ -484,23 +606,23 @@ TEST_CASE("RegexManager::remove_last_regex removes last added `highlight` rule",
 
 	const auto INPUT = std::string("xfoobarx");
 
-	auto input = INPUT;
+	auto input = StflRichText::from_plaintext(INPUT);
 	rxman.quote_and_highlight(input, "articlelist");
-	REQUIRE(input == "x<0>foo<1>bar</>x");
+	REQUIRE(input.stfl_quoted() == "x<0>foo<1>bar</>x");
 
-	input = INPUT;
+	input = StflRichText::from_plaintext(INPUT);
 	rxman.quote_and_highlight(input, "feedlist");
-	REQUIRE(input == INPUT);
+	REQUIRE(input.stfl_quoted() == INPUT);
 
 	REQUIRE_NOTHROW(rxman.remove_last_regex("articlelist"));
 
-	input = INPUT;
+	input = StflRichText::from_plaintext(INPUT);
 	rxman.quote_and_highlight(input, "articlelist");
-	REQUIRE(input == "x<0>foo</>barx");
+	REQUIRE(input.stfl_quoted() == "x<0>foo</>barx");
 
-	input = INPUT;
+	input = StflRichText::from_plaintext(INPUT);
 	rxman.quote_and_highlight(input, "feedlist");
-	REQUIRE(input == INPUT);
+	REQUIRE(input.stfl_quoted() == INPUT);
 }
 
 TEST_CASE("RegexManager::remove_last_regex does not crash if there are "
@@ -554,41 +676,68 @@ TEST_CASE("RegexManager uses POSIX extended regex syntax",
 	// ensure that we're using EREs, these tests try stuff that's *not*
 	// supported by EREs.
 	//
+	// FreeBSD 13 returns an error from regexec() instead of failing the match
+	// like other OSes do. That's why we wrap our tests in a try-catch.
+	//
 	// Ideas gleaned from https://www.regular-expressions.info/refcharacters.html
 
 	RegexManager rxman;
 
 	// Supported by Perl, PCRE, PHP and others
 	SECTION("No support for escape sequence") {
-		rxman.handle_action("highlight", {"articlelist", R"#(\Q*]+\E)#", "red"});
+		try {
+			rxman.handle_action("highlight", {"articlelist", R"#(\Q*]+\E)#", "red"});
+		} catch (const ConfigHandlerException& e) {
+			const std::string expected(
+				R"#(`\Q*]+\E' is not a valid regular expression: trailing backslash (\))#");
+			REQUIRE(e.what() == expected);
+		}
 
-		std::string input = "*]+";
+		auto input = StflRichText::from_plaintext("*]+");
 		rxman.quote_and_highlight(input, "articlelist");
-		REQUIRE(input == "*]+");
+		REQUIRE(input.stfl_quoted() == "*]+");
 	}
 
 	SECTION("No support for hexadecimal escape") {
-		rxman.handle_action("highlight", {"articlelist", R"#(^va\x6Cue)#", "red"});
+		try {
+			rxman.handle_action("highlight", {"articlelist", R"#(^va\x6Cue)#", "red"});
+		} catch (const ConfigHandlerException& e) {
+			const std::string expected(
+				R"#(`^va\x6Cue' is not a valid regular expression: trailing backslash (\))#");
+			REQUIRE(e.what() == expected);
+		}
 
-		std::string input = "value";
+		auto input = StflRichText::from_plaintext("value");
 		rxman.quote_and_highlight(input, "articlelist");
-		REQUIRE(input == "value");
+		REQUIRE(input.stfl_quoted() == "value");
 	}
 
 	SECTION("No support for \\a as alert/bell control character") {
-		rxman.handle_action("highlight", {"articlelist", R"#(\a)#", "red"});
+		try {
+			rxman.handle_action("highlight", {"articlelist", R"#(\a)#", "red"});
+		} catch (const ConfigHandlerException& e) {
+			const std::string expected(
+				R"#(`\a' is not a valid regular expression: trailing backslash (\))#");
+			REQUIRE(e.what() == expected);
+		}
 
-		std::string input = "\x07";
+		auto input = StflRichText::from_plaintext("\x07");
 		rxman.quote_and_highlight(input, "articlelist");
-		REQUIRE(input == "\x07");
+		REQUIRE(input.stfl_quoted() == "\x07");
 	}
 
 	SECTION("No support for \\b as backspace control character") {
-		rxman.handle_action("highlight", {"articlelist", R"#(\b)#", "red"});
+		try {
+			rxman.handle_action("highlight", {"articlelist", R"#(\b)#", "red"});
+		} catch (const ConfigHandlerException& e) {
+			const std::string expected(
+				R"#(`\b' is not a valid regular expression: trailing backslash (\))#");
+			REQUIRE(e.what() == expected);
+		}
 
-		std::string input = "\x08";
+		auto input = StflRichText::from_plaintext("\x08");
 		rxman.quote_and_highlight(input, "articlelist");
-		REQUIRE(input == "\x08");
+		REQUIRE(input.stfl_quoted() == "\x08");
 	}
 
 	// If you add more checks to this test, consider adding the same to Matcher tests
@@ -598,20 +747,20 @@ TEST_CASE("quote_and_highlight() does not break existing tags like <unread>",
 	"[RegexManager]")
 {
 	RegexManager rxman;
-	std::string input =  "<unread>This entry is unread</>";
+	auto input = StflRichText::from_quoted("<unread>This entry is unread</>");
 
 	WHEN("matching `read`") {
 		const std::string output = "<unread>This entry is un<0>read</>";
 		rxman.handle_action("highlight", {"article", "read", "red"});
 		rxman.quote_and_highlight(input, "article");
-		REQUIRE(input == output);
+		REQUIRE(input.stfl_quoted() == output);
 	}
 
 	WHEN("matching `unread`") {
 		const std::string output = "<unread>This entry is <0>unread</>";
 		rxman.handle_action("highlight", {"article", "unread", "red"});
 		rxman.quote_and_highlight(input, "article");
-		REQUIRE(input == output);
+		REQUIRE(input.stfl_quoted() == output);
 	}
 
 	WHEN("matching the full line") {
@@ -620,7 +769,7 @@ TEST_CASE("quote_and_highlight() does not break existing tags like <unread>",
 		THEN("the <unread> tag is overwritten") {
 			const std::string output = "<0>This entry is unread</>";
 			rxman.quote_and_highlight(input, "article");
-			REQUIRE(input == output);
+			REQUIRE(input.stfl_quoted() == output);
 		}
 	}
 }
@@ -629,7 +778,7 @@ TEST_CASE("quote_and_highlight() ignores tags when matching the regular expressi
 	"[RegexManager]")
 {
 	RegexManager rxman;
-	std::string input =  "<unread>This entry is unread</>";
+	auto input = StflRichText::from_quoted("<unread>This entry is unread</>");
 
 	WHEN("matching text at the start of the line") {
 		rxman.handle_action("highlight", {"article", "^This", "red"});
@@ -637,7 +786,7 @@ TEST_CASE("quote_and_highlight() ignores tags when matching the regular expressi
 		THEN("the <unread> tag should be ignored") {
 			const std::string output = "<0>This<unread> entry is unread</>";
 			rxman.quote_and_highlight(input, "article");
-			REQUIRE(input == output);
+			REQUIRE(input.stfl_quoted() == output);
 		}
 	}
 
@@ -647,18 +796,18 @@ TEST_CASE("quote_and_highlight() ignores tags when matching the regular expressi
 		THEN("the closing tag `</>` (related to <unread>) should be ignored") {
 			const std::string output = "<unread>This entry is <0>unread</>";
 			rxman.quote_and_highlight(input, "article");
-			REQUIRE(input == output);
+			REQUIRE(input.stfl_quoted() == output);
 		}
 	}
 
 	WHEN("matching text which contains `<u>...</>` markers (added by HTML renderer)") {
-		input = "Some<u>thing</> is underlined";
+		input = StflRichText::from_quoted("Some<u>thing</> is underlined");
 		rxman.handle_action("highlight", {"article", "Something", "red"});
 
 		THEN("the tags should be ignored when matching text with a regular expression") {
 			const std::string output = "<0>Something</> is underlined";
 			rxman.quote_and_highlight(input, "article");
-			REQUIRE(input == output);
+			REQUIRE(input.stfl_quoted() == output);
 		}
 	}
 }
@@ -667,7 +816,8 @@ TEST_CASE("quote_and_highlight() generates a sensible output when multiple match
 	"[RegexManager]")
 {
 	RegexManager rxman;
-	std::string input = "The quick brown fox jumps over the lazy dog";
+	auto input =
+		StflRichText::from_plaintext("The quick brown fox jumps over the lazy dog");
 
 	WHEN("a second match is completely inside of the first match") {
 		rxman.handle_action("highlight", {"article", "The quick brown", "red"});
@@ -677,7 +827,7 @@ TEST_CASE("quote_and_highlight() generates a sensible output when multiple match
 			const std::string output =
 				"<0>The <1>quick<0> brown</> fox jumps over the lazy dog";
 			rxman.quote_and_highlight(input, "article");
-			REQUIRE(input == output);
+			REQUIRE(input.stfl_quoted() == output);
 		}
 	}
 
@@ -689,7 +839,7 @@ TEST_CASE("quote_and_highlight() generates a sensible output when multiple match
 			const std::string output =
 				"<1>The quick brown</> fox jumps over the lazy dog";
 			rxman.quote_and_highlight(input, "article");
-			REQUIRE(input == output);
+			REQUIRE(input.stfl_quoted() == output);
 		}
 	}
 
@@ -701,7 +851,7 @@ TEST_CASE("quote_and_highlight() generates a sensible output when multiple match
 			const std::string output =
 				"The <0>quick <1>brown fox</> jumps over the lazy dog";
 			rxman.quote_and_highlight(input, "article");
-			REQUIRE(input == output);
+			REQUIRE(input.stfl_quoted() == output);
 		}
 	}
 
@@ -713,7 +863,7 @@ TEST_CASE("quote_and_highlight() generates a sensible output when multiple match
 			const std::string output =
 				"The <1>quick brown<0> fox</> jumps over the lazy dog";
 			rxman.quote_and_highlight(input, "article");
-			REQUIRE(input == output);
+			REQUIRE(input.stfl_quoted() == output);
 		}
 	}
 
@@ -726,7 +876,7 @@ TEST_CASE("quote_and_highlight() generates a sensible output when multiple match
 			const std::string output =
 				"The <0>quick <2>brown fox<1> jumps over<0> the lazy dog</>";
 			rxman.quote_and_highlight(input, "article");
-			REQUIRE(input == output);
+			REQUIRE(input.stfl_quoted() == output);
 		}
 	}
 }
@@ -735,12 +885,12 @@ TEST_CASE("quote_and_highlight() keeps stfl-encoded angle brackets and allows ma
 	"[RegexManager]")
 {
 	RegexManager rxman;
-	std::string input = "<unread>title with <>literal> angle brackets</>";
+	auto input = StflRichText::from_quoted("<unread>title with <>literal> angle brackets</>");
 
 	SECTION("stfl-encoded angle brackets are kept/restored") {
 		const std::string output = "<unread>title with <>literal> angle brackets</>";
 		rxman.quote_and_highlight(input, "article");
-		REQUIRE(input == output);
+		REQUIRE(input.stfl_quoted() == output);
 	}
 
 	SECTION("angle brackets can be matched directly") {
@@ -748,230 +898,6 @@ TEST_CASE("quote_and_highlight() keeps stfl-encoded angle brackets and allows ma
 			"<unread>title with <0><>literal><unread> angle brackets</>";
 		rxman.handle_action("highlight", {"article", "<literal>", "red"});
 		rxman.quote_and_highlight(input, "article");
-		REQUIRE(input == output);
-	}
-}
-
-TEST_CASE("extract_style_tags() returns map which links locations to tags from input string",
-	"[RegexManager]")
-{
-	RegexManager rxman;
-
-	SECTION("input with no tags at all") {
-		std::string input = "The quick brown fox jumps over the lazy dog";
-		const std::string output = "The quick brown fox jumps over the lazy dog";
-		auto tags = rxman.extract_style_tags(input);
-		REQUIRE(input == output);
-		REQUIRE(tags.size() == 0);
-	}
-
-	SECTION("input with various tags") {
-		std::string input = "<unread>title <0>with <u>underline<0> and style</>";
-		const std::string output = "title with underline and style";
-		auto tags = rxman.extract_style_tags(input);
-		REQUIRE(input == output);
-		REQUIRE(tags[0]  == "<unread>");
-		REQUIRE(tags[6]  == "<0>");
-		REQUIRE(tags[11] == "<u>");
-		REQUIRE(tags[20] == "<0>");
-		REQUIRE(tags[30] == "</>");
-		REQUIRE(tags.size() == 5);
-	}
-}
-
-TEST_CASE("extract_style_tags() keeps stfl-encoded angle brackets in string",
-	"[RegexManager]")
-{
-	RegexManager rxman;
-
-	SECTION("stfl-encoded angle brackets should be preserved") {
-		std::string input = "<unread>title with <>literal> angle brackets</>";
-		const std::string output = "title with <literal> angle brackets";
-		auto tags = rxman.extract_style_tags(input);
-		REQUIRE(input == output);
-		REQUIRE(tags[0]  == "<unread>");
-		REQUIRE(tags[35] == "</>");
-		REQUIRE(tags.size() == 2);
-	}
-}
-
-TEST_CASE("extract_style_tags() ignores invalid characters",
-	"[RegexManager]")
-{
-	RegexManager rxman;
-	// Different output might be acceptable as this input would/should be
-	// invalid but it makes sense to keep a consistent result when refactoring.
-
-	SECTION("double tag open") {
-		std::string input = "<unread>title <with <u>repeated tag opening bracket</>";
-		const std::string output = "title <with repeated tag opening bracket";
-		auto tags = rxman.extract_style_tags(input);
-		REQUIRE(input == output);
-		REQUIRE(tags[0]  == "<unread>");
-		REQUIRE(tags[12] == "<u>");
-		REQUIRE(tags[40] == "</>");
-		REQUIRE(tags.size() == 3);
-	}
-
-	SECTION("unmatched '<' at end of line") {
-		std::string input = "some <u>underlining</>, nothing else<";
-		const std::string output = "some underlining, nothing else<";
-		auto tags = rxman.extract_style_tags(input);
-		REQUIRE(input == output);
-		REQUIRE(tags[5]  == "<u>");
-		REQUIRE(tags[16]  == "</>");
-		REQUIRE(tags.size() == 2);
-	}
-}
-
-TEST_CASE("insert_style_tags() adds tags into string at correct positions",
-	"[RegexManager]")
-{
-	RegexManager rxman;
-	std::string input = "This is a sentence";
-
-	SECTION("string does not change if no tags are specified") {
-		std::map<size_t, std::string> tags;
-		const std::string output = "This is a sentence";
-		rxman.insert_style_tags(input, tags);
-		REQUIRE(input == output);
-	}
-
-	SECTION("tags are added at the correct location") {
-		std::map<size_t, std::string> tags = {
-			{0, "<0>"},
-			{1, "<1>"},
-			{10, "<hello>"},
-			{18, "</>"},
-		};
-		const std::string output = "<0>T<1>his is a <hello>sentence</>";
-		rxman.insert_style_tags(input, tags);
-		REQUIRE(input == output);
-	}
-}
-
-TEST_CASE("insert_style_tags() stfl-encodes angle brackets existing in input string",
-	"[RegexManager]")
-{
-	RegexManager rxman;
-	std::string input = ">>This <is> a sentence with brackets<<";
-
-	SECTION("brackets are stfl-encoded") {
-		std::map<size_t, std::string> tags;
-		const std::string output = ">>This <>is> a sentence with brackets<><>";
-		rxman.insert_style_tags(input, tags);
-		REQUIRE(input == output);
-	}
-
-	SECTION("brackets are stfl-encoded and tags are inserted") {
-		std::map<size_t, std::string> tags = {
-			{0, "<0>"},
-			{1, "<1>"},
-			{6, "<hello>"},
-			{38, "</>"},
-		};
-		const std::string output =
-			"<0>><1>>This<hello> <>is> a sentence with brackets<><></>";
-		rxman.insert_style_tags(input, tags);
-		REQUIRE(input == output);
-	}
-}
-
-TEST_CASE("insert_style_tags() does not crash on invalid input",
-	"[RegexManager]")
-{
-	RegexManager rxman;
-	std::string input = "test this";
-
-	SECTION("tags with a position outside  of the string are ignored") {
-		std::map<size_t, std::string> tags = {
-			{0, "<test>"},
-			{9, "<in>"},
-			{10, "<out>"},
-		};
-		const std::string output = "<test>test this<in>";
-		rxman.insert_style_tags(input, tags);
-		REQUIRE(input == output);
-	}
-}
-
-TEST_CASE("merge_style_tag() removes tags between start and end positions",
-	"[RegexManager]")
-{
-	RegexManager rxman;
-	const std::string new_tag = "<test>";
-	std::map<size_t, std::string> tags = {
-		{0, "<0>"},
-		{5, "<1>"},
-		{7, "<2>"},
-		{10, "<3>"},
-		{15, "</>"},
-	};
-
-	rxman.merge_style_tag(tags, new_tag, 2, 10);
-	REQUIRE(tags[0] == "<0>");
-	REQUIRE(tags[2] == new_tag);
-	REQUIRE(tags[10] == "<3>");
-	REQUIRE(tags[15] == "</>");
-	REQUIRE(tags.size() == 4);
-}
-
-TEST_CASE("merge_style_tag() restores previous tag after the inserted tag if necessary",
-	"[RegexManager]")
-{
-	RegexManager rxman;
-	const std::string new_tag = "<test>";
-	std::map<size_t, std::string> tags = {
-		{0, "<0>"},
-		{5, "<1>"},
-		{10, "</>"},
-	};
-
-	SECTION("end before tag switch so restore first tag") {
-		rxman.merge_style_tag(tags, new_tag, 0, 4);
-		REQUIRE(tags[0] == new_tag);
-		REQUIRE(tags[4] == "<0>");
-		REQUIRE(tags[5] == "<1>");
-		REQUIRE(tags[10] == "</>");
-		REQUIRE(tags.size() == 4);
-	}
-
-	SECTION("end on tag switch so no need to restore anything") {
-		rxman.merge_style_tag(tags, new_tag, 0, 5);
-		REQUIRE(tags[0] == new_tag);
-		REQUIRE(tags[5] == "<1>");
-		REQUIRE(tags[10] == "</>");
-		REQUIRE(tags.size() == 3);
-	}
-
-	SECTION("end after a closing tag (</>) so close at the end") {
-		SECTION("on the closing tag") {
-			rxman.merge_style_tag(tags, new_tag, 0, 10);
-			REQUIRE(tags[0] == new_tag);
-			REQUIRE(tags[10] == "</>");
-			REQUIRE(tags.size() == 2);
-		}
-
-		SECTION("after the closing tag") {
-			rxman.merge_style_tag(tags, new_tag, 0, 11);
-			REQUIRE(tags[0] == new_tag);
-			REQUIRE(tags[11] == "</>");
-			REQUIRE(tags.size() == 2);
-		}
-	}
-}
-
-TEST_CASE("merge_style_tag() does not crash on invalid input",
-	"[RegexManager]")
-{
-	RegexManager rxman;
-	std::map<size_t, std::string> tags;
-	const std::string new_tag = "<test>";
-
-	SECTION("ignore tag merging if `end <= start`") {
-		rxman.merge_style_tag(tags, new_tag, 0, 0);
-		rxman.merge_style_tag(tags, new_tag, 1, 0);
-		rxman.merge_style_tag(tags, new_tag, 5, 4);
-		REQUIRE(tags.size() == 0);
+		REQUIRE(input.stfl_quoted() == output);
 	}
 }
